.. currentmodule:: pyscenarios

What's New
==========

.. ipython:: python
   :suppress:

    import numpy as np
    import dask.array as da
    np.random.seed(123456)

.. _whats-new.0.1.0:

v0.1.0 (2018-05-27)
-------------------

Initial release.